# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing
import uuid
from json.decoder import JSONDecodeError

from .....core.api_error import ApiError
from .....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .....core.http_response import AsyncHttpResponse, HttpResponse
from .....core.jsonable_encoder import jsonable_encoder
from .....core.pydantic_utilities import parse_obj_as
from .....core.request_options import RequestOptions
from ....commons.errors.entity_not_found_error import EntityNotFoundError
from ....commons.errors.http_request_validations_error import HttpRequestValidationsError
from ....commons.errors.unauthorized_error import UnauthorizedError
from ....commons.errors.unprocessable_entity_error import UnprocessableEntityError
from ....commons.types.entity_not_found_error_message import EntityNotFoundErrorMessage
from ....commons.types.page_token import PageToken
from ....commons.types.provider_credentialing_span_id import ProviderCredentialingSpanId
from ....commons.types.regions import Regions
from ....commons.types.request_validation_error import RequestValidationError
from ....commons.types.unauthorized_error_message import UnauthorizedErrorMessage
from ....commons.types.unprocessable_entity_error_message import UnprocessableEntityErrorMessage
from .types.facility_credentialing_span import FacilityCredentialingSpan
from .types.facility_credentialing_span_id import FacilityCredentialingSpanId
from .types.facility_credentialing_span_page import FacilityCredentialingSpanPage
from .types.provider_credentialing_span import ProviderCredentialingSpan
from .types.provider_credentialing_span_page import ProviderCredentialingSpanPage

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawV2Client:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def create_facility(
        self,
        *,
        service_facility_id: uuid.UUID,
        contracting_provider_id: uuid.UUID,
        payer_uuid: uuid.UUID,
        start_date: typing.Optional[dt.date] = OMIT,
        end_date: typing.Optional[dt.date] = OMIT,
        submitted_date: typing.Optional[dt.date] = OMIT,
        payer_loaded_date: typing.Optional[dt.date] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[FacilityCredentialingSpan]:
        """
        Parameters
        ----------
        service_facility_id : uuid.UUID
            The ID of the service facility covered by the credentialing span.

        contracting_provider_id : uuid.UUID
            The ID of the billing provider for which the service facility is covered by the credentialing span.

        payer_uuid : uuid.UUID
            The ID of the payer covered by the credentialing span.

        start_date : typing.Optional[dt.date]
            Start date of the credentialing span.

        end_date : typing.Optional[dt.date]
            End date of the credentialing span.

        submitted_date : typing.Optional[dt.date]
            Date that the credential paperwork was submitted.

        payer_loaded_date : typing.Optional[dt.date]
            Date that the payer loaded the credentialing span into their system.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[FacilityCredentialingSpan]
        """
        _response = self._client_wrapper.httpx_client.request(
            "api/provider-credentialing-span/v2/facility",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="POST",
            json={
                "service_facility_id": service_facility_id,
                "contracting_provider_id": contracting_provider_id,
                "payer_uuid": payer_uuid,
                "start_date": start_date,
                "end_date": end_date,
                "submitted_date": submitted_date,
                "payer_loaded_date": payer_loaded_date,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                FacilityCredentialingSpan,
                parse_obj_as(
                    type_=FacilityCredentialingSpan,  # type: ignore
                    object_=_response_json,
                ),
            )
            return HttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "HttpRequestValidationsError":
                raise HttpRequestValidationsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.List[RequestValidationError],
                        parse_obj_as(
                            type_=typing.List[RequestValidationError],  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnauthorizedError":
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnauthorizedErrorMessage,
                        parse_obj_as(
                            type_=UnauthorizedErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_facility(
        self,
        facility_credentialing_id: FacilityCredentialingSpanId,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[FacilityCredentialingSpan]:
        """
        Parameters
        ----------
        facility_credentialing_id : FacilityCredentialingSpanId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[FacilityCredentialingSpan]
        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/provider-credentialing-span/v2/facility/{jsonable_encoder(facility_credentialing_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="GET",
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                FacilityCredentialingSpan,
                parse_obj_as(
                    type_=FacilityCredentialingSpan,  # type: ignore
                    object_=_response_json,
                ),
            )
            return HttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityNotFoundErrorMessage,
                        parse_obj_as(
                            type_=EntityNotFoundErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnauthorizedError":
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnauthorizedErrorMessage,
                        parse_obj_as(
                            type_=UnauthorizedErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_all_facilities(
        self,
        *,
        limit: typing.Optional[int] = None,
        page_token: typing.Optional[PageToken] = None,
        payer_uuid: typing.Optional[uuid.UUID] = None,
        contracting_provider_id: typing.Optional[uuid.UUID] = None,
        service_facility_id: typing.Optional[uuid.UUID] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[FacilityCredentialingSpanPage]:
        """
        Parameters
        ----------
        limit : typing.Optional[int]
            Maximum number of entities per page, defaults to 100.

        page_token : typing.Optional[PageToken]

        payer_uuid : typing.Optional[uuid.UUID]
            Filter by payer.

        contracting_provider_id : typing.Optional[uuid.UUID]
            Filter to a particular contracting provider.

        service_facility_id : typing.Optional[uuid.UUID]
            Filter to a particular service facility.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[FacilityCredentialingSpanPage]
        """
        _response = self._client_wrapper.httpx_client.request(
            "api/provider-credentialing-span/v2/facility",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="GET",
            params={
                "limit": limit,
                "page_token": page_token,
                "payer_uuid": payer_uuid,
                "contracting_provider_id": contracting_provider_id,
                "service_facility_id": service_facility_id,
            },
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                FacilityCredentialingSpanPage,
                parse_obj_as(
                    type_=FacilityCredentialingSpanPage,  # type: ignore
                    object_=_response_json,
                ),
            )
            return HttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "UnauthorizedError":
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnauthorizedErrorMessage,
                        parse_obj_as(
                            type_=UnauthorizedErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnprocessableEntityError":
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnprocessableEntityErrorMessage,
                        parse_obj_as(
                            type_=UnprocessableEntityErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def delete_facility(
        self,
        facility_credentialing_id: FacilityCredentialingSpanId,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[None]:
        """
        Soft deletes a credentialing span rate from the system.

        Parameters
        ----------
        facility_credentialing_id : FacilityCredentialingSpanId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[None]
        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/provider-credentialing-span/v2/facility/{jsonable_encoder(facility_credentialing_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="DELETE",
            request_options=request_options,
        )
        if 200 <= _response.status_code < 300:
            return HttpResponse(response=_response, data=None)
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityNotFoundErrorMessage,
                        parse_obj_as(
                            type_=EntityNotFoundErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnauthorizedError":
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnauthorizedErrorMessage,
                        parse_obj_as(
                            type_=UnauthorizedErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def update_facility(
        self,
        facility_credentialing_id: FacilityCredentialingSpanId,
        *,
        contracting_provider_id: uuid.UUID,
        payer_uuid: typing.Optional[uuid.UUID] = OMIT,
        start_date: typing.Optional[dt.date] = OMIT,
        end_date: typing.Optional[dt.date] = OMIT,
        regions: typing.Optional[Regions] = OMIT,
        submitted_date: typing.Optional[dt.date] = OMIT,
        payer_loaded_date: typing.Optional[dt.date] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[FacilityCredentialingSpan]:
        """
        Parameters
        ----------
        facility_credentialing_id : FacilityCredentialingSpanId

        contracting_provider_id : uuid.UUID
            The ID of the billing provider for which the service facility is covered by the credentialing span.

        payer_uuid : typing.Optional[uuid.UUID]
            The ID of the payer doing the credentialing.

        start_date : typing.Optional[dt.date]
            Start date of the credentialing span.

        end_date : typing.Optional[dt.date]
            End date of the credentialing span.

        regions : typing.Optional[Regions]
            The states covered by the credentialing span. A span may be national and cover all states.

        submitted_date : typing.Optional[dt.date]
            Date that the credential paperwork was submitted.

        payer_loaded_date : typing.Optional[dt.date]
            Date that the payer loaded the credentialing span into their system.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[FacilityCredentialingSpan]
        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/provider-credentialing-span/v2/facility/{jsonable_encoder(facility_credentialing_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="PATCH",
            json={
                "contracting_provider_id": contracting_provider_id,
                "payer_uuid": payer_uuid,
                "start_date": start_date,
                "end_date": end_date,
                "regions": regions,
                "submitted_date": submitted_date,
                "payer_loaded_date": payer_loaded_date,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                FacilityCredentialingSpan,
                parse_obj_as(
                    type_=FacilityCredentialingSpan,  # type: ignore
                    object_=_response_json,
                ),
            )
            return HttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityNotFoundErrorMessage,
                        parse_obj_as(
                            type_=EntityNotFoundErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "HttpRequestValidationsError":
                raise HttpRequestValidationsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.List[RequestValidationError],
                        parse_obj_as(
                            type_=typing.List[RequestValidationError],  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnauthorizedError":
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnauthorizedErrorMessage,
                        parse_obj_as(
                            type_=UnauthorizedErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnprocessableEntityError":
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnprocessableEntityErrorMessage,
                        parse_obj_as(
                            type_=UnprocessableEntityErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def create(
        self,
        *,
        rendering_provider_id: uuid.UUID,
        contracting_provider_id: uuid.UUID,
        payer_uuid: uuid.UUID,
        regions: Regions,
        start_date: typing.Optional[dt.date] = OMIT,
        end_date: typing.Optional[dt.date] = OMIT,
        submitted_date: typing.Optional[dt.date] = OMIT,
        payer_loaded_date: typing.Optional[dt.date] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[ProviderCredentialingSpan]:
        """
        Parameters
        ----------
        rendering_provider_id : uuid.UUID
            The ID of the rendering provider covered by the credentialing span.

        contracting_provider_id : uuid.UUID
            The ID of the billing provider for which the service facility is covered by the credentialing span.

        payer_uuid : uuid.UUID
            The ID of the payer covered by the credentialing span.

        regions : Regions
            The states covered by the credentialing span. A span may be national and cover all states.

        start_date : typing.Optional[dt.date]
            Start date of the credentialing span.

        end_date : typing.Optional[dt.date]
            End date of the credentialing span.

        submitted_date : typing.Optional[dt.date]
            Date that the credential paperwork was submitted.

        payer_loaded_date : typing.Optional[dt.date]
            Date that the payer loaded the credentialing span into their system.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ProviderCredentialingSpan]
        """
        _response = self._client_wrapper.httpx_client.request(
            "api/provider-credentialing-span/v2",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="POST",
            json={
                "rendering_provider_id": rendering_provider_id,
                "contracting_provider_id": contracting_provider_id,
                "payer_uuid": payer_uuid,
                "start_date": start_date,
                "end_date": end_date,
                "regions": regions,
                "submitted_date": submitted_date,
                "payer_loaded_date": payer_loaded_date,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                ProviderCredentialingSpan,
                parse_obj_as(
                    type_=ProviderCredentialingSpan,  # type: ignore
                    object_=_response_json,
                ),
            )
            return HttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "HttpRequestValidationsError":
                raise HttpRequestValidationsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.List[RequestValidationError],
                        parse_obj_as(
                            type_=typing.List[RequestValidationError],  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnauthorizedError":
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnauthorizedErrorMessage,
                        parse_obj_as(
                            type_=UnauthorizedErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get(
        self,
        provider_credentialing_id: ProviderCredentialingSpanId,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[ProviderCredentialingSpan]:
        """
        Parameters
        ----------
        provider_credentialing_id : ProviderCredentialingSpanId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ProviderCredentialingSpan]
        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/provider-credentialing-span/v2/{jsonable_encoder(provider_credentialing_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="GET",
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                ProviderCredentialingSpan,
                parse_obj_as(
                    type_=ProviderCredentialingSpan,  # type: ignore
                    object_=_response_json,
                ),
            )
            return HttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityNotFoundErrorMessage,
                        parse_obj_as(
                            type_=EntityNotFoundErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnauthorizedError":
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnauthorizedErrorMessage,
                        parse_obj_as(
                            type_=UnauthorizedErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get_all(
        self,
        *,
        limit: typing.Optional[int] = None,
        page_token: typing.Optional[PageToken] = None,
        payer_uuid: typing.Optional[uuid.UUID] = None,
        provider_id: typing.Optional[uuid.UUID] = None,
        as_rendering_provider: typing.Optional[bool] = None,
        as_contracting_provider: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[ProviderCredentialingSpanPage]:
        """
        Parameters
        ----------
        limit : typing.Optional[int]
            Maximum number of entities per page, defaults to 100.

        page_token : typing.Optional[PageToken]

        payer_uuid : typing.Optional[uuid.UUID]
            Filter by payer.

        provider_id : typing.Optional[uuid.UUID]
            Filter to a particular provider. Use in conjunction as_rendering_provider and as_contracting_provider.

        as_rendering_provider : typing.Optional[bool]
            Filter to credentialing spans where the provider is a rendering provider. To use this filter provider_id is required.

        as_contracting_provider : typing.Optional[bool]
            Filter to credentialing spans where the provider is a contracting provider. To use this filter provider_id is required.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ProviderCredentialingSpanPage]
        """
        _response = self._client_wrapper.httpx_client.request(
            "api/provider-credentialing-span/v2",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="GET",
            params={
                "limit": limit,
                "page_token": page_token,
                "payer_uuid": payer_uuid,
                "provider_id": provider_id,
                "as_rendering_provider": as_rendering_provider,
                "as_contracting_provider": as_contracting_provider,
            },
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                ProviderCredentialingSpanPage,
                parse_obj_as(
                    type_=ProviderCredentialingSpanPage,  # type: ignore
                    object_=_response_json,
                ),
            )
            return HttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "UnauthorizedError":
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnauthorizedErrorMessage,
                        parse_obj_as(
                            type_=UnauthorizedErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnprocessableEntityError":
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnprocessableEntityErrorMessage,
                        parse_obj_as(
                            type_=UnprocessableEntityErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def delete(
        self,
        provider_credentialing_id: ProviderCredentialingSpanId,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[None]:
        """
        Soft deletes a credentialing span rate from the system.

        Parameters
        ----------
        provider_credentialing_id : ProviderCredentialingSpanId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[None]
        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/provider-credentialing-span/v2/{jsonable_encoder(provider_credentialing_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="DELETE",
            request_options=request_options,
        )
        if 200 <= _response.status_code < 300:
            return HttpResponse(response=_response, data=None)
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityNotFoundErrorMessage,
                        parse_obj_as(
                            type_=EntityNotFoundErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnauthorizedError":
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnauthorizedErrorMessage,
                        parse_obj_as(
                            type_=UnauthorizedErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def update(
        self,
        provider_credentialing_id: ProviderCredentialingSpanId,
        *,
        contracting_provider_id: typing.Optional[uuid.UUID] = OMIT,
        payer_uuid: typing.Optional[uuid.UUID] = OMIT,
        start_date: typing.Optional[dt.date] = OMIT,
        end_date: typing.Optional[dt.date] = OMIT,
        regions: typing.Optional[Regions] = OMIT,
        submitted_date: typing.Optional[dt.date] = OMIT,
        payer_loaded_date: typing.Optional[dt.date] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[ProviderCredentialingSpan]:
        """
        Parameters
        ----------
        provider_credentialing_id : ProviderCredentialingSpanId

        contracting_provider_id : typing.Optional[uuid.UUID]
            The ID of the billing provider for which the service facility is covered by the credentialing span.

        payer_uuid : typing.Optional[uuid.UUID]
            The ID of the payer doing the credentialing.

        start_date : typing.Optional[dt.date]
            Start date of the credentialing span.

        end_date : typing.Optional[dt.date]
            End date of the credentialing span.

        regions : typing.Optional[Regions]
            The states covered by the credentialing span. A span may be national and cover all states.

        submitted_date : typing.Optional[dt.date]
            Date that the credential paperwork was submitted.

        payer_loaded_date : typing.Optional[dt.date]
            Date that the payer loaded the credentialing span into their system.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ProviderCredentialingSpan]
        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/provider-credentialing-span/v2/{jsonable_encoder(provider_credentialing_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="PATCH",
            json={
                "contracting_provider_id": contracting_provider_id,
                "payer_uuid": payer_uuid,
                "start_date": start_date,
                "end_date": end_date,
                "regions": regions,
                "submitted_date": submitted_date,
                "payer_loaded_date": payer_loaded_date,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                ProviderCredentialingSpan,
                parse_obj_as(
                    type_=ProviderCredentialingSpan,  # type: ignore
                    object_=_response_json,
                ),
            )
            return HttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityNotFoundErrorMessage,
                        parse_obj_as(
                            type_=EntityNotFoundErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "HttpRequestValidationsError":
                raise HttpRequestValidationsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.List[RequestValidationError],
                        parse_obj_as(
                            type_=typing.List[RequestValidationError],  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnauthorizedError":
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnauthorizedErrorMessage,
                        parse_obj_as(
                            type_=UnauthorizedErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnprocessableEntityError":
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnprocessableEntityErrorMessage,
                        parse_obj_as(
                            type_=UnprocessableEntityErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawV2Client:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def create_facility(
        self,
        *,
        service_facility_id: uuid.UUID,
        contracting_provider_id: uuid.UUID,
        payer_uuid: uuid.UUID,
        start_date: typing.Optional[dt.date] = OMIT,
        end_date: typing.Optional[dt.date] = OMIT,
        submitted_date: typing.Optional[dt.date] = OMIT,
        payer_loaded_date: typing.Optional[dt.date] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[FacilityCredentialingSpan]:
        """
        Parameters
        ----------
        service_facility_id : uuid.UUID
            The ID of the service facility covered by the credentialing span.

        contracting_provider_id : uuid.UUID
            The ID of the billing provider for which the service facility is covered by the credentialing span.

        payer_uuid : uuid.UUID
            The ID of the payer covered by the credentialing span.

        start_date : typing.Optional[dt.date]
            Start date of the credentialing span.

        end_date : typing.Optional[dt.date]
            End date of the credentialing span.

        submitted_date : typing.Optional[dt.date]
            Date that the credential paperwork was submitted.

        payer_loaded_date : typing.Optional[dt.date]
            Date that the payer loaded the credentialing span into their system.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[FacilityCredentialingSpan]
        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/provider-credentialing-span/v2/facility",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="POST",
            json={
                "service_facility_id": service_facility_id,
                "contracting_provider_id": contracting_provider_id,
                "payer_uuid": payer_uuid,
                "start_date": start_date,
                "end_date": end_date,
                "submitted_date": submitted_date,
                "payer_loaded_date": payer_loaded_date,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                FacilityCredentialingSpan,
                parse_obj_as(
                    type_=FacilityCredentialingSpan,  # type: ignore
                    object_=_response_json,
                ),
            )
            return AsyncHttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "HttpRequestValidationsError":
                raise HttpRequestValidationsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.List[RequestValidationError],
                        parse_obj_as(
                            type_=typing.List[RequestValidationError],  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnauthorizedError":
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnauthorizedErrorMessage,
                        parse_obj_as(
                            type_=UnauthorizedErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_facility(
        self,
        facility_credentialing_id: FacilityCredentialingSpanId,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[FacilityCredentialingSpan]:
        """
        Parameters
        ----------
        facility_credentialing_id : FacilityCredentialingSpanId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[FacilityCredentialingSpan]
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/provider-credentialing-span/v2/facility/{jsonable_encoder(facility_credentialing_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="GET",
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                FacilityCredentialingSpan,
                parse_obj_as(
                    type_=FacilityCredentialingSpan,  # type: ignore
                    object_=_response_json,
                ),
            )
            return AsyncHttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityNotFoundErrorMessage,
                        parse_obj_as(
                            type_=EntityNotFoundErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnauthorizedError":
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnauthorizedErrorMessage,
                        parse_obj_as(
                            type_=UnauthorizedErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_all_facilities(
        self,
        *,
        limit: typing.Optional[int] = None,
        page_token: typing.Optional[PageToken] = None,
        payer_uuid: typing.Optional[uuid.UUID] = None,
        contracting_provider_id: typing.Optional[uuid.UUID] = None,
        service_facility_id: typing.Optional[uuid.UUID] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[FacilityCredentialingSpanPage]:
        """
        Parameters
        ----------
        limit : typing.Optional[int]
            Maximum number of entities per page, defaults to 100.

        page_token : typing.Optional[PageToken]

        payer_uuid : typing.Optional[uuid.UUID]
            Filter by payer.

        contracting_provider_id : typing.Optional[uuid.UUID]
            Filter to a particular contracting provider.

        service_facility_id : typing.Optional[uuid.UUID]
            Filter to a particular service facility.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[FacilityCredentialingSpanPage]
        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/provider-credentialing-span/v2/facility",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="GET",
            params={
                "limit": limit,
                "page_token": page_token,
                "payer_uuid": payer_uuid,
                "contracting_provider_id": contracting_provider_id,
                "service_facility_id": service_facility_id,
            },
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                FacilityCredentialingSpanPage,
                parse_obj_as(
                    type_=FacilityCredentialingSpanPage,  # type: ignore
                    object_=_response_json,
                ),
            )
            return AsyncHttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "UnauthorizedError":
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnauthorizedErrorMessage,
                        parse_obj_as(
                            type_=UnauthorizedErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnprocessableEntityError":
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnprocessableEntityErrorMessage,
                        parse_obj_as(
                            type_=UnprocessableEntityErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def delete_facility(
        self,
        facility_credentialing_id: FacilityCredentialingSpanId,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[None]:
        """
        Soft deletes a credentialing span rate from the system.

        Parameters
        ----------
        facility_credentialing_id : FacilityCredentialingSpanId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[None]
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/provider-credentialing-span/v2/facility/{jsonable_encoder(facility_credentialing_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="DELETE",
            request_options=request_options,
        )
        if 200 <= _response.status_code < 300:
            return AsyncHttpResponse(response=_response, data=None)
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityNotFoundErrorMessage,
                        parse_obj_as(
                            type_=EntityNotFoundErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnauthorizedError":
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnauthorizedErrorMessage,
                        parse_obj_as(
                            type_=UnauthorizedErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def update_facility(
        self,
        facility_credentialing_id: FacilityCredentialingSpanId,
        *,
        contracting_provider_id: uuid.UUID,
        payer_uuid: typing.Optional[uuid.UUID] = OMIT,
        start_date: typing.Optional[dt.date] = OMIT,
        end_date: typing.Optional[dt.date] = OMIT,
        regions: typing.Optional[Regions] = OMIT,
        submitted_date: typing.Optional[dt.date] = OMIT,
        payer_loaded_date: typing.Optional[dt.date] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[FacilityCredentialingSpan]:
        """
        Parameters
        ----------
        facility_credentialing_id : FacilityCredentialingSpanId

        contracting_provider_id : uuid.UUID
            The ID of the billing provider for which the service facility is covered by the credentialing span.

        payer_uuid : typing.Optional[uuid.UUID]
            The ID of the payer doing the credentialing.

        start_date : typing.Optional[dt.date]
            Start date of the credentialing span.

        end_date : typing.Optional[dt.date]
            End date of the credentialing span.

        regions : typing.Optional[Regions]
            The states covered by the credentialing span. A span may be national and cover all states.

        submitted_date : typing.Optional[dt.date]
            Date that the credential paperwork was submitted.

        payer_loaded_date : typing.Optional[dt.date]
            Date that the payer loaded the credentialing span into their system.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[FacilityCredentialingSpan]
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/provider-credentialing-span/v2/facility/{jsonable_encoder(facility_credentialing_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="PATCH",
            json={
                "contracting_provider_id": contracting_provider_id,
                "payer_uuid": payer_uuid,
                "start_date": start_date,
                "end_date": end_date,
                "regions": regions,
                "submitted_date": submitted_date,
                "payer_loaded_date": payer_loaded_date,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                FacilityCredentialingSpan,
                parse_obj_as(
                    type_=FacilityCredentialingSpan,  # type: ignore
                    object_=_response_json,
                ),
            )
            return AsyncHttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityNotFoundErrorMessage,
                        parse_obj_as(
                            type_=EntityNotFoundErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "HttpRequestValidationsError":
                raise HttpRequestValidationsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.List[RequestValidationError],
                        parse_obj_as(
                            type_=typing.List[RequestValidationError],  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnauthorizedError":
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnauthorizedErrorMessage,
                        parse_obj_as(
                            type_=UnauthorizedErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnprocessableEntityError":
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnprocessableEntityErrorMessage,
                        parse_obj_as(
                            type_=UnprocessableEntityErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def create(
        self,
        *,
        rendering_provider_id: uuid.UUID,
        contracting_provider_id: uuid.UUID,
        payer_uuid: uuid.UUID,
        regions: Regions,
        start_date: typing.Optional[dt.date] = OMIT,
        end_date: typing.Optional[dt.date] = OMIT,
        submitted_date: typing.Optional[dt.date] = OMIT,
        payer_loaded_date: typing.Optional[dt.date] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[ProviderCredentialingSpan]:
        """
        Parameters
        ----------
        rendering_provider_id : uuid.UUID
            The ID of the rendering provider covered by the credentialing span.

        contracting_provider_id : uuid.UUID
            The ID of the billing provider for which the service facility is covered by the credentialing span.

        payer_uuid : uuid.UUID
            The ID of the payer covered by the credentialing span.

        regions : Regions
            The states covered by the credentialing span. A span may be national and cover all states.

        start_date : typing.Optional[dt.date]
            Start date of the credentialing span.

        end_date : typing.Optional[dt.date]
            End date of the credentialing span.

        submitted_date : typing.Optional[dt.date]
            Date that the credential paperwork was submitted.

        payer_loaded_date : typing.Optional[dt.date]
            Date that the payer loaded the credentialing span into their system.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ProviderCredentialingSpan]
        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/provider-credentialing-span/v2",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="POST",
            json={
                "rendering_provider_id": rendering_provider_id,
                "contracting_provider_id": contracting_provider_id,
                "payer_uuid": payer_uuid,
                "start_date": start_date,
                "end_date": end_date,
                "regions": regions,
                "submitted_date": submitted_date,
                "payer_loaded_date": payer_loaded_date,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                ProviderCredentialingSpan,
                parse_obj_as(
                    type_=ProviderCredentialingSpan,  # type: ignore
                    object_=_response_json,
                ),
            )
            return AsyncHttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "HttpRequestValidationsError":
                raise HttpRequestValidationsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.List[RequestValidationError],
                        parse_obj_as(
                            type_=typing.List[RequestValidationError],  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnauthorizedError":
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnauthorizedErrorMessage,
                        parse_obj_as(
                            type_=UnauthorizedErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get(
        self,
        provider_credentialing_id: ProviderCredentialingSpanId,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[ProviderCredentialingSpan]:
        """
        Parameters
        ----------
        provider_credentialing_id : ProviderCredentialingSpanId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ProviderCredentialingSpan]
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/provider-credentialing-span/v2/{jsonable_encoder(provider_credentialing_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="GET",
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                ProviderCredentialingSpan,
                parse_obj_as(
                    type_=ProviderCredentialingSpan,  # type: ignore
                    object_=_response_json,
                ),
            )
            return AsyncHttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityNotFoundErrorMessage,
                        parse_obj_as(
                            type_=EntityNotFoundErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnauthorizedError":
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnauthorizedErrorMessage,
                        parse_obj_as(
                            type_=UnauthorizedErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get_all(
        self,
        *,
        limit: typing.Optional[int] = None,
        page_token: typing.Optional[PageToken] = None,
        payer_uuid: typing.Optional[uuid.UUID] = None,
        provider_id: typing.Optional[uuid.UUID] = None,
        as_rendering_provider: typing.Optional[bool] = None,
        as_contracting_provider: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[ProviderCredentialingSpanPage]:
        """
        Parameters
        ----------
        limit : typing.Optional[int]
            Maximum number of entities per page, defaults to 100.

        page_token : typing.Optional[PageToken]

        payer_uuid : typing.Optional[uuid.UUID]
            Filter by payer.

        provider_id : typing.Optional[uuid.UUID]
            Filter to a particular provider. Use in conjunction as_rendering_provider and as_contracting_provider.

        as_rendering_provider : typing.Optional[bool]
            Filter to credentialing spans where the provider is a rendering provider. To use this filter provider_id is required.

        as_contracting_provider : typing.Optional[bool]
            Filter to credentialing spans where the provider is a contracting provider. To use this filter provider_id is required.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ProviderCredentialingSpanPage]
        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/provider-credentialing-span/v2",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="GET",
            params={
                "limit": limit,
                "page_token": page_token,
                "payer_uuid": payer_uuid,
                "provider_id": provider_id,
                "as_rendering_provider": as_rendering_provider,
                "as_contracting_provider": as_contracting_provider,
            },
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                ProviderCredentialingSpanPage,
                parse_obj_as(
                    type_=ProviderCredentialingSpanPage,  # type: ignore
                    object_=_response_json,
                ),
            )
            return AsyncHttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "UnauthorizedError":
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnauthorizedErrorMessage,
                        parse_obj_as(
                            type_=UnauthorizedErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnprocessableEntityError":
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnprocessableEntityErrorMessage,
                        parse_obj_as(
                            type_=UnprocessableEntityErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def delete(
        self,
        provider_credentialing_id: ProviderCredentialingSpanId,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[None]:
        """
        Soft deletes a credentialing span rate from the system.

        Parameters
        ----------
        provider_credentialing_id : ProviderCredentialingSpanId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[None]
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/provider-credentialing-span/v2/{jsonable_encoder(provider_credentialing_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="DELETE",
            request_options=request_options,
        )
        if 200 <= _response.status_code < 300:
            return AsyncHttpResponse(response=_response, data=None)
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityNotFoundErrorMessage,
                        parse_obj_as(
                            type_=EntityNotFoundErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnauthorizedError":
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnauthorizedErrorMessage,
                        parse_obj_as(
                            type_=UnauthorizedErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def update(
        self,
        provider_credentialing_id: ProviderCredentialingSpanId,
        *,
        contracting_provider_id: typing.Optional[uuid.UUID] = OMIT,
        payer_uuid: typing.Optional[uuid.UUID] = OMIT,
        start_date: typing.Optional[dt.date] = OMIT,
        end_date: typing.Optional[dt.date] = OMIT,
        regions: typing.Optional[Regions] = OMIT,
        submitted_date: typing.Optional[dt.date] = OMIT,
        payer_loaded_date: typing.Optional[dt.date] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[ProviderCredentialingSpan]:
        """
        Parameters
        ----------
        provider_credentialing_id : ProviderCredentialingSpanId

        contracting_provider_id : typing.Optional[uuid.UUID]
            The ID of the billing provider for which the service facility is covered by the credentialing span.

        payer_uuid : typing.Optional[uuid.UUID]
            The ID of the payer doing the credentialing.

        start_date : typing.Optional[dt.date]
            Start date of the credentialing span.

        end_date : typing.Optional[dt.date]
            End date of the credentialing span.

        regions : typing.Optional[Regions]
            The states covered by the credentialing span. A span may be national and cover all states.

        submitted_date : typing.Optional[dt.date]
            Date that the credential paperwork was submitted.

        payer_loaded_date : typing.Optional[dt.date]
            Date that the payer loaded the credentialing span into their system.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ProviderCredentialingSpan]
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/provider-credentialing-span/v2/{jsonable_encoder(provider_credentialing_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="PATCH",
            json={
                "contracting_provider_id": contracting_provider_id,
                "payer_uuid": payer_uuid,
                "start_date": start_date,
                "end_date": end_date,
                "regions": regions,
                "submitted_date": submitted_date,
                "payer_loaded_date": payer_loaded_date,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        if 200 <= _response.status_code < 300:
            _data = typing.cast(
                ProviderCredentialingSpan,
                parse_obj_as(
                    type_=ProviderCredentialingSpan,  # type: ignore
                    object_=_response_json,
                ),
            )
            return AsyncHttpResponse(response=_response, data=_data)
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        EntityNotFoundErrorMessage,
                        parse_obj_as(
                            type_=EntityNotFoundErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "HttpRequestValidationsError":
                raise HttpRequestValidationsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.List[RequestValidationError],
                        parse_obj_as(
                            type_=typing.List[RequestValidationError],  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnauthorizedError":
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnauthorizedErrorMessage,
                        parse_obj_as(
                            type_=UnauthorizedErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
            if _response_json["errorName"] == "UnprocessableEntityError":
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        UnprocessableEntityErrorMessage,
                        parse_obj_as(
                            type_=UnprocessableEntityErrorMessage,  # type: ignore
                            object_=_response_json["content"],
                        ),
                    ),
                )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from .....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .....core.request_options import RequestOptions
from ....commons.types.invoice_id import InvoiceId
from ....commons.types.page_token import PageToken
from ....commons.types.sort_direction import SortDirection
from ....financials.types.invoice_update import InvoiceUpdate
from ....financials.types.note_update import NoteUpdate
from ....non_insurance_payers.resources.v_1.types.non_insurance_payer_id import NonInsurancePayerId
from .raw_client import AsyncRawV1Client, RawV1Client
from .types.non_insurance_payer_payment import NonInsurancePayerPayment
from .types.non_insurance_payer_payment_create import NonInsurancePayerPaymentCreate
from .types.non_insurance_payer_payment_id import NonInsurancePayerPaymentId
from .types.non_insurance_payer_payment_sort_field import NonInsurancePayerPaymentSortField
from .types.non_insurance_payer_payments_page import NonInsurancePayerPaymentsPage

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class V1Client:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawV1Client(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawV1Client:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawV1Client
        """
        return self._raw_client

    def get_multi(
        self,
        *,
        limit: typing.Optional[int] = None,
        non_insurance_payer_id: typing.Optional[NonInsurancePayerId] = None,
        check_number: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        invoice_id: typing.Optional[InvoiceId] = None,
        sort: typing.Optional[NonInsurancePayerPaymentSortField] = None,
        sort_direction: typing.Optional[SortDirection] = None,
        page_token: typing.Optional[PageToken] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> NonInsurancePayerPaymentsPage:
        """
        Returns all non-insurance payer payments

        Parameters
        ----------
        limit : typing.Optional[int]
            Defaults to 100. The value must be greater than 0 and less than 1000.

        non_insurance_payer_id : typing.Optional[NonInsurancePayerId]

        check_number : typing.Optional[typing.Union[str, typing.Sequence[str]]]

        invoice_id : typing.Optional[InvoiceId]

        sort : typing.Optional[NonInsurancePayerPaymentSortField]
            Defaults to refund_timestamp

        sort_direction : typing.Optional[SortDirection]
            Sort direction. Defaults to descending order if not provided.

        page_token : typing.Optional[PageToken]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        NonInsurancePayerPaymentsPage

        Examples
        --------
        from candid import CandidApiClient

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.non_insurance_payer_payments.v_1.get_multi()
        """
        _response = self._raw_client.get_multi(
            limit=limit,
            non_insurance_payer_id=non_insurance_payer_id,
            check_number=check_number,
            invoice_id=invoice_id,
            sort=sort,
            sort_direction=sort_direction,
            page_token=page_token,
            request_options=request_options,
        )
        return _response.data

    def get(
        self,
        non_insurance_payer_payment_id: NonInsurancePayerPaymentId,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> NonInsurancePayerPayment:
        """
        Retrieves a previously created non-insurance payer payment by its `non_insurance_payer_payment_id`.

        Parameters
        ----------
        non_insurance_payer_payment_id : NonInsurancePayerPaymentId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        NonInsurancePayerPayment

        Examples
        --------
        import uuid

        from candid import CandidApiClient

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.non_insurance_payer_payments.v_1.get(
            non_insurance_payer_payment_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
        )
        """
        _response = self._raw_client.get(non_insurance_payer_payment_id, request_options=request_options)
        return _response.data

    def create(
        self, *, request: NonInsurancePayerPaymentCreate, request_options: typing.Optional[RequestOptions] = None
    ) -> NonInsurancePayerPayment:
        """
        Parameters
        ----------
        request : NonInsurancePayerPaymentCreate

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        NonInsurancePayerPayment

        Examples
        --------
        import uuid

        from candid import CandidApiClient
        from candid.resources.financials import (
            AllocationCreate,
            AllocationTargetCreate_ServiceLineById,
        )
        from candid.resources.non_insurance_payer_payments.resources.v_1 import (
            NonInsurancePayerPaymentCreate,
        )

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.non_insurance_payer_payments.v_1.create(
            request=NonInsurancePayerPaymentCreate(
                non_insurance_payer_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
                amount_cents=1,
                allocations=[
                    AllocationCreate(
                        amount_cents=1,
                        target=AllocationTargetCreate_ServiceLineById(
                            value=uuid.UUID(
                                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                            )
                        ),
                    ),
                    AllocationCreate(
                        amount_cents=1,
                        target=AllocationTargetCreate_ServiceLineById(
                            value=uuid.UUID(
                                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                            )
                        ),
                    ),
                ],
            ),
        )
        """
        _response = self._raw_client.create(request=request, request_options=request_options)
        return _response.data

    def update(
        self,
        non_insurance_payer_payment_id: NonInsurancePayerPaymentId,
        *,
        payment_timestamp: typing.Optional[dt.datetime] = OMIT,
        payment_note: typing.Optional[NoteUpdate] = OMIT,
        invoice_id: typing.Optional[InvoiceUpdate] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> NonInsurancePayerPayment:
        """
        Parameters
        ----------
        non_insurance_payer_payment_id : NonInsurancePayerPaymentId

        payment_timestamp : typing.Optional[dt.datetime]

        payment_note : typing.Optional[NoteUpdate]

        invoice_id : typing.Optional[InvoiceUpdate]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        NonInsurancePayerPayment

        Examples
        --------
        import uuid

        from candid import CandidApiClient

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.non_insurance_payer_payments.v_1.update(
            non_insurance_payer_payment_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
        )
        """
        _response = self._raw_client.update(
            non_insurance_payer_payment_id,
            payment_timestamp=payment_timestamp,
            payment_note=payment_note,
            invoice_id=invoice_id,
            request_options=request_options,
        )
        return _response.data

    def delete(
        self,
        non_insurance_payer_payment_id: NonInsurancePayerPaymentId,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> None:
        """
        Deletes the non-insurance payer payment record matching the provided `non_insurance_payer_payment_id`.

        Parameters
        ----------
        non_insurance_payer_payment_id : NonInsurancePayerPaymentId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import uuid

        from candid import CandidApiClient

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.non_insurance_payer_payments.v_1.delete(
            non_insurance_payer_payment_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
        )
        """
        _response = self._raw_client.delete(non_insurance_payer_payment_id, request_options=request_options)
        return _response.data


class AsyncV1Client:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawV1Client(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawV1Client:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawV1Client
        """
        return self._raw_client

    async def get_multi(
        self,
        *,
        limit: typing.Optional[int] = None,
        non_insurance_payer_id: typing.Optional[NonInsurancePayerId] = None,
        check_number: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        invoice_id: typing.Optional[InvoiceId] = None,
        sort: typing.Optional[NonInsurancePayerPaymentSortField] = None,
        sort_direction: typing.Optional[SortDirection] = None,
        page_token: typing.Optional[PageToken] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> NonInsurancePayerPaymentsPage:
        """
        Returns all non-insurance payer payments

        Parameters
        ----------
        limit : typing.Optional[int]
            Defaults to 100. The value must be greater than 0 and less than 1000.

        non_insurance_payer_id : typing.Optional[NonInsurancePayerId]

        check_number : typing.Optional[typing.Union[str, typing.Sequence[str]]]

        invoice_id : typing.Optional[InvoiceId]

        sort : typing.Optional[NonInsurancePayerPaymentSortField]
            Defaults to refund_timestamp

        sort_direction : typing.Optional[SortDirection]
            Sort direction. Defaults to descending order if not provided.

        page_token : typing.Optional[PageToken]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        NonInsurancePayerPaymentsPage

        Examples
        --------
        import asyncio

        from candid import AsyncCandidApiClient

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.non_insurance_payer_payments.v_1.get_multi()


        asyncio.run(main())
        """
        _response = await self._raw_client.get_multi(
            limit=limit,
            non_insurance_payer_id=non_insurance_payer_id,
            check_number=check_number,
            invoice_id=invoice_id,
            sort=sort,
            sort_direction=sort_direction,
            page_token=page_token,
            request_options=request_options,
        )
        return _response.data

    async def get(
        self,
        non_insurance_payer_payment_id: NonInsurancePayerPaymentId,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> NonInsurancePayerPayment:
        """
        Retrieves a previously created non-insurance payer payment by its `non_insurance_payer_payment_id`.

        Parameters
        ----------
        non_insurance_payer_payment_id : NonInsurancePayerPaymentId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        NonInsurancePayerPayment

        Examples
        --------
        import asyncio
        import uuid

        from candid import AsyncCandidApiClient

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.non_insurance_payer_payments.v_1.get(
                non_insurance_payer_payment_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.get(non_insurance_payer_payment_id, request_options=request_options)
        return _response.data

    async def create(
        self, *, request: NonInsurancePayerPaymentCreate, request_options: typing.Optional[RequestOptions] = None
    ) -> NonInsurancePayerPayment:
        """
        Parameters
        ----------
        request : NonInsurancePayerPaymentCreate

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        NonInsurancePayerPayment

        Examples
        --------
        import asyncio
        import uuid

        from candid import AsyncCandidApiClient
        from candid.resources.financials import (
            AllocationCreate,
            AllocationTargetCreate_ServiceLineById,
        )
        from candid.resources.non_insurance_payer_payments.resources.v_1 import (
            NonInsurancePayerPaymentCreate,
        )

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.non_insurance_payer_payments.v_1.create(
                request=NonInsurancePayerPaymentCreate(
                    non_insurance_payer_id=uuid.UUID(
                        "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                    ),
                    amount_cents=1,
                    allocations=[
                        AllocationCreate(
                            amount_cents=1,
                            target=AllocationTargetCreate_ServiceLineById(
                                value=uuid.UUID(
                                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                                )
                            ),
                        ),
                        AllocationCreate(
                            amount_cents=1,
                            target=AllocationTargetCreate_ServiceLineById(
                                value=uuid.UUID(
                                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                                )
                            ),
                        ),
                    ],
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create(request=request, request_options=request_options)
        return _response.data

    async def update(
        self,
        non_insurance_payer_payment_id: NonInsurancePayerPaymentId,
        *,
        payment_timestamp: typing.Optional[dt.datetime] = OMIT,
        payment_note: typing.Optional[NoteUpdate] = OMIT,
        invoice_id: typing.Optional[InvoiceUpdate] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> NonInsurancePayerPayment:
        """
        Parameters
        ----------
        non_insurance_payer_payment_id : NonInsurancePayerPaymentId

        payment_timestamp : typing.Optional[dt.datetime]

        payment_note : typing.Optional[NoteUpdate]

        invoice_id : typing.Optional[InvoiceUpdate]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        NonInsurancePayerPayment

        Examples
        --------
        import asyncio
        import uuid

        from candid import AsyncCandidApiClient

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.non_insurance_payer_payments.v_1.update(
                non_insurance_payer_payment_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.update(
            non_insurance_payer_payment_id,
            payment_timestamp=payment_timestamp,
            payment_note=payment_note,
            invoice_id=invoice_id,
            request_options=request_options,
        )
        return _response.data

    async def delete(
        self,
        non_insurance_payer_payment_id: NonInsurancePayerPaymentId,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> None:
        """
        Deletes the non-insurance payer payment record matching the provided `non_insurance_payer_payment_id`.

        Parameters
        ----------
        non_insurance_payer_payment_id : NonInsurancePayerPaymentId

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import asyncio
        import uuid

        from candid import AsyncCandidApiClient

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.non_insurance_payer_payments.v_1.delete(
                non_insurance_payer_payment_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete(non_insurance_payer_payment_id, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

from ........core import enum

T_Result = typing.TypeVar("T_Result")


class SpecializationCategory(enum.StrEnum):
    BEHAVIORAL_HEALTH_THERAPY = "BEHAVIORAL_HEALTH_THERAPY"
    CARDIOLOGY = "CARDIOLOGY"
    DERMATOLOGY = "DERMATOLOGY"
    ENDOCRINOLOGY = "ENDOCRINOLOGY"
    ENT = "ENT"
    GASTROENTEROLOGY = "GASTROENTEROLOGY"
    GENERAL_SURGERY = "GENERAL_SURGERY"
    GENETICS = "GENETICS"
    HEMATOLOGY = "HEMATOLOGY"
    INFECTIOUS_DISEASE = "INFECTIOUS_DISEASE"
    NEUROLOGY = "NEUROLOGY"
    NUTRITIONAL_THERAPY = "NUTRITIONAL_THERAPY"
    OB_GYN = "OB_GYN"
    ONCOLOGY = "ONCOLOGY"
    OPHTHALMOLOGY = "OPHTHALMOLOGY"
    ORTHOPEDICS = "ORTHOPEDICS"
    PAIN_MANAGEMENT = "PAIN_MANAGEMENT"
    PEDIATRICS = "PEDIATRICS"
    PHYSICAL_THERAPY = "PHYSICAL_THERAPY"
    PODIATRY = "PODIATRY"
    PRIMARY_CARE = "PRIMARY_CARE"
    PSYCHIATRY = "PSYCHIATRY"
    PULMONOLOGY = "PULMONOLOGY"
    RADIOLOGY = "RADIOLOGY"
    RHEUMATOLOGY = "RHEUMATOLOGY"
    SCREENING = "SCREENING"
    UROLOGY = "UROLOGY"
    OTHER = "OTHER"
    _UNKNOWN = "__SPECIALIZATIONCATEGORY_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "SpecializationCategory":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        behavioral_health_therapy: typing.Callable[[], T_Result],
        cardiology: typing.Callable[[], T_Result],
        dermatology: typing.Callable[[], T_Result],
        endocrinology: typing.Callable[[], T_Result],
        ent: typing.Callable[[], T_Result],
        gastroenterology: typing.Callable[[], T_Result],
        general_surgery: typing.Callable[[], T_Result],
        genetics: typing.Callable[[], T_Result],
        hematology: typing.Callable[[], T_Result],
        infectious_disease: typing.Callable[[], T_Result],
        neurology: typing.Callable[[], T_Result],
        nutritional_therapy: typing.Callable[[], T_Result],
        ob_gyn: typing.Callable[[], T_Result],
        oncology: typing.Callable[[], T_Result],
        ophthalmology: typing.Callable[[], T_Result],
        orthopedics: typing.Callable[[], T_Result],
        pain_management: typing.Callable[[], T_Result],
        pediatrics: typing.Callable[[], T_Result],
        physical_therapy: typing.Callable[[], T_Result],
        podiatry: typing.Callable[[], T_Result],
        primary_care: typing.Callable[[], T_Result],
        psychiatry: typing.Callable[[], T_Result],
        pulmonology: typing.Callable[[], T_Result],
        radiology: typing.Callable[[], T_Result],
        rheumatology: typing.Callable[[], T_Result],
        screening: typing.Callable[[], T_Result],
        urology: typing.Callable[[], T_Result],
        other: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is SpecializationCategory.BEHAVIORAL_HEALTH_THERAPY:
            return behavioral_health_therapy()
        if self is SpecializationCategory.CARDIOLOGY:
            return cardiology()
        if self is SpecializationCategory.DERMATOLOGY:
            return dermatology()
        if self is SpecializationCategory.ENDOCRINOLOGY:
            return endocrinology()
        if self is SpecializationCategory.ENT:
            return ent()
        if self is SpecializationCategory.GASTROENTEROLOGY:
            return gastroenterology()
        if self is SpecializationCategory.GENERAL_SURGERY:
            return general_surgery()
        if self is SpecializationCategory.GENETICS:
            return genetics()
        if self is SpecializationCategory.HEMATOLOGY:
            return hematology()
        if self is SpecializationCategory.INFECTIOUS_DISEASE:
            return infectious_disease()
        if self is SpecializationCategory.NEUROLOGY:
            return neurology()
        if self is SpecializationCategory.NUTRITIONAL_THERAPY:
            return nutritional_therapy()
        if self is SpecializationCategory.OB_GYN:
            return ob_gyn()
        if self is SpecializationCategory.ONCOLOGY:
            return oncology()
        if self is SpecializationCategory.OPHTHALMOLOGY:
            return ophthalmology()
        if self is SpecializationCategory.ORTHOPEDICS:
            return orthopedics()
        if self is SpecializationCategory.PAIN_MANAGEMENT:
            return pain_management()
        if self is SpecializationCategory.PEDIATRICS:
            return pediatrics()
        if self is SpecializationCategory.PHYSICAL_THERAPY:
            return physical_therapy()
        if self is SpecializationCategory.PODIATRY:
            return podiatry()
        if self is SpecializationCategory.PRIMARY_CARE:
            return primary_care()
        if self is SpecializationCategory.PSYCHIATRY:
            return psychiatry()
        if self is SpecializationCategory.PULMONOLOGY:
            return pulmonology()
        if self is SpecializationCategory.RADIOLOGY:
            return radiology()
        if self is SpecializationCategory.RHEUMATOLOGY:
            return rheumatology()
        if self is SpecializationCategory.SCREENING:
            return screening()
        if self is SpecializationCategory.UROLOGY:
            return urology()
        if self is SpecializationCategory.OTHER:
            return other()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

import typing

from ......core import enum

T_Result = typing.TypeVar("T_Result")


class PrincipalProcedureInformationCodeQualifier(enum.StrEnum):
    CBBR = "BBR"
    """
    International Classification of Diseases Clinical Modification (ICD-10-PCS) Principal Procedure Codes
    """

    CBR = "BR"
    """
    International Classification of Diseases Clinical Modification (ICD-9-CM) Principal Procedure Codes
    """

    CCAH = "CAH"
    """
    Advanced Billing Concepts (ABC) Codes
    """

    _UNKNOWN = "__PRINCIPALPROCEDUREINFORMATIONCODEQUALIFIER_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "PrincipalProcedureInformationCodeQualifier":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        cbbr: typing.Callable[[], T_Result],
        cbr: typing.Callable[[], T_Result],
        ccah: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is PrincipalProcedureInformationCodeQualifier.CBBR:
            return cbbr()
        if self is PrincipalProcedureInformationCodeQualifier.CBR:
            return cbr()
        if self is PrincipalProcedureInformationCodeQualifier.CCAH:
            return ccah()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

import typing

from ......core import enum

T_Result = typing.TypeVar("T_Result")


class ChargeCaptureClaimCreationStatus(enum.StrEnum):
    NOT_STARTED = "not-started"
    IN_ERROR = "in-error"
    SUCCESSFUL = "successful"
    SUCCESSFUL_DRY_RUN = "successful-dry-run"
    ABORTED = "aborted"
    HELD = "held"
    """
    This Claim Creation has potential charges that are in a planned state, the Claim Creation will be held until those charges are converted
    """

    _UNKNOWN = "__CHARGECAPTURECLAIMCREATIONSTATUS_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "ChargeCaptureClaimCreationStatus":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        not_started: typing.Callable[[], T_Result],
        in_error: typing.Callable[[], T_Result],
        successful: typing.Callable[[], T_Result],
        successful_dry_run: typing.Callable[[], T_Result],
        aborted: typing.Callable[[], T_Result],
        held: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is ChargeCaptureClaimCreationStatus.NOT_STARTED:
            return not_started()
        if self is ChargeCaptureClaimCreationStatus.IN_ERROR:
            return in_error()
        if self is ChargeCaptureClaimCreationStatus.SUCCESSFUL:
            return successful()
        if self is ChargeCaptureClaimCreationStatus.SUCCESSFUL_DRY_RUN:
            return successful_dry_run()
        if self is ChargeCaptureClaimCreationStatus.ABORTED:
            return aborted()
        if self is ChargeCaptureClaimCreationStatus.HELD:
            return held()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ........core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....common.types.patient_id import PatientId
from .....common.types.relationship import Relationship
from .....eligibility_checks.resources.v_1.types.eligibility_check_metadata import EligibilityCheckMetadata
from .coverage_benefits import CoverageBenefits
from .coverage_status import CoverageStatus
from .insurance_plan import InsurancePlan
from .latest_eligibility_check import LatestEligibilityCheck
from .subscriber import Subscriber


class MutableCoverage(UniversalBaseModel):
    status: CoverageStatus = pydantic.Field()
    """
    The status indiciating if the coverage is active or not.
    """

    subscriber: Subscriber = pydantic.Field()
    """
    The party who has signed-up for or 'owns' the contractual relationship to the policy or to whom the benefit of the policy for services rendered to them or their family is due.
    """

    relationship: Relationship = pydantic.Field()
    """
    The relationship of beneficiary (patient) to the subscriber. https://hl7.org/fhir/valueset-relationship.html
    """

    patient: PatientId = pydantic.Field()
    """
    The canonical Candid patient UUID corresponding with the patient who benefits from the insurance coverage
    """

    insurance_plan: InsurancePlan
    verified: bool = pydantic.Field()
    """
    A boolean indicating if the coverage has been verified by a user.
    """

    eligibility_checks: typing.Optional[typing.List[EligibilityCheckMetadata]] = pydantic.Field(default=None)
    """
    A list of eligibility check metadata that have been initiated on this coverage.
    """

    latest_eligibility_check: typing.Optional[LatestEligibilityCheck] = pydantic.Field(default=None)
    """
    The latest eligibility check metadata that has been initiated on this coverage.
    """

    benefits: typing.Optional[CoverageBenefits] = pydantic.Field(default=None)
    """
    The eligibility of the patient for the coverage, manually verified by users.
    """

    orcon: typing.Optional[bool] = pydantic.Field(default=None)
    """
    ORCON (Originator Controlled) - When set to true, the Candid system will hide this coverage from downstream integrations. Updates made in the Candid UI will unset this flag. Defaults to false.
    """

    auto_update_enabled: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Default to true. When set to true, the Candid system will automatically update this coverage with the latest eligibility check benefits information. Auto update behavior is also set at the eligibilityConfig org level configuration.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....commons.types.facility_type_code import FacilityTypeCode
from .....commons.types.network_type import NetworkType
from .....commons.types.payer_plan_group_id import PayerPlanGroupId
from .....commons.types.procedure_modifier import ProcedureModifier
from .....commons.types.state import State
from .....organization_providers.resources.v_2.types.license_type import LicenseType
from .....organization_providers.resources.v_2.types.organization_provider_id import OrganizationProviderId
from .....payers.resources.v_3.types.payer_uuid import PayerUuid


class OptionalDimensions(UniversalBaseModel):
    """
    A dimensions object where all properties are optional.
    """

    payer_uuid: typing.Optional[PayerUuid] = None
    organization_billing_provider_id: typing.Optional[OrganizationProviderId] = None
    states: typing.Set[State]
    zip_codes: typing.Set[str]
    license_types: typing.Set[LicenseType]
    facility_type_codes: typing.Set[FacilityTypeCode]
    network_types: typing.Set[NetworkType]
    payer_plan_group_ids: typing.Set[PayerPlanGroupId]
    cpt_code: typing.Optional[str] = None
    modifiers: typing.Set[ProcedureModifier]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from ......core import enum

T_Result = typing.TypeVar("T_Result")


class EmploymentStatus(enum.StrEnum):
    ACTIVE = "ACTIVE"
    TERMINATED = "TERMINATED"
    _UNKNOWN = "__EMPLOYMENTSTATUS_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "EmploymentStatus":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        active: typing.Callable[[], T_Result],
        terminated: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is EmploymentStatus.ACTIVE:
            return active()
        if self is EmploymentStatus.TERMINATED:
            return terminated()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .cash_pay_payer_error import CashPayPayerError
    from .encounter_external_id_uniqueness_error import EncounterExternalIdUniquenessError
    from .encounter_guarantor_missing_contact_info_error import EncounterGuarantorMissingContactInfoError
    from .encounter_patient_control_number_uniqueness_error import EncounterPatientControlNumberUniquenessError
    from .encounter_rendering_or_attending_provider_required import EncounterRenderingOrAttendingProviderRequired
    from .invalid_tag_names_error import InvalidTagNamesError
    from .payer_plan_group_payer_does_not_match_insurance_card_http_error import (
        PayerPlanGroupPayerDoesNotMatchInsuranceCardHttpError,
    )
    from .schema_instance_validation_http_failure import SchemaInstanceValidationHttpFailure
_dynamic_imports: typing.Dict[str, str] = {
    "CashPayPayerError": ".cash_pay_payer_error",
    "EncounterExternalIdUniquenessError": ".encounter_external_id_uniqueness_error",
    "EncounterGuarantorMissingContactInfoError": ".encounter_guarantor_missing_contact_info_error",
    "EncounterPatientControlNumberUniquenessError": ".encounter_patient_control_number_uniqueness_error",
    "EncounterRenderingOrAttendingProviderRequired": ".encounter_rendering_or_attending_provider_required",
    "InvalidTagNamesError": ".invalid_tag_names_error",
    "PayerPlanGroupPayerDoesNotMatchInsuranceCardHttpError": ".payer_plan_group_payer_does_not_match_insurance_card_http_error",
    "SchemaInstanceValidationHttpFailure": ".schema_instance_validation_http_failure",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "CashPayPayerError",
    "EncounterExternalIdUniquenessError",
    "EncounterGuarantorMissingContactInfoError",
    "EncounterPatientControlNumberUniquenessError",
    "EncounterRenderingOrAttendingProviderRequired",
    "InvalidTagNamesError",
    "PayerPlanGroupPayerDoesNotMatchInsuranceCardHttpError",
    "SchemaInstanceValidationHttpFailure",
]



# This file was auto-generated by Fern from our API Definition.

import typing

from ......core import enum

T_Result = typing.TypeVar("T_Result")


class SexualOrientation(enum.StrEnum):
    HETEROSEXUAL = "HETEROSEXUAL"
    HOMOSEXUAL = "HOMOSEXUAL"
    BISEXUAL = "BISEXUAL"
    TWO_SPIRIT = "TWO_SPIRIT"
    OTHER = "OTHER"
    UNKNOWN = "UNKNOWN"
    REFUSED = "REFUSED"
    _UNKNOWN = "__SEXUALORIENTATION_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "SexualOrientation":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        heterosexual: typing.Callable[[], T_Result],
        homosexual: typing.Callable[[], T_Result],
        bisexual: typing.Callable[[], T_Result],
        two_spirit: typing.Callable[[], T_Result],
        other: typing.Callable[[], T_Result],
        unknown: typing.Callable[[], T_Result],
        refused: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is SexualOrientation.HETEROSEXUAL:
            return heterosexual()
        if self is SexualOrientation.HOMOSEXUAL:
            return homosexual()
        if self is SexualOrientation.BISEXUAL:
            return bisexual()
        if self is SexualOrientation.TWO_SPIRIT:
            return two_spirit()
        if self is SexualOrientation.OTHER:
            return other()
        if self is SexualOrientation.UNKNOWN:
            return unknown()
        if self is SexualOrientation.REFUSED:
            return refused()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ........core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .related_entity_contact import RelatedEntityContact
from .service_type_code import ServiceTypeCode


class BenefitsRelatedEntity(UniversalBaseModel):
    entity_identifier: typing.Optional[str] = pydantic.Field(alias="entityIdentifier", default=None)
    entity_type: typing.Optional[str] = pydantic.Field(alias="entityType", default=None)
    entity_name: typing.Optional[str] = pydantic.Field(alias="entityName", default=None)
    contact_information: typing.Optional[typing.List[RelatedEntityContact]] = pydantic.Field(
        alias="contactInformation", default=None
    )
    service_type_codes: typing.Optional[typing.List[ServiceTypeCode]] = pydantic.Field(
        alias="serviceTypeCodes", default=None
    )

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .condition_information import ConditionInformation
from .external_cause_of_injury import ExternalCauseOfInjury
from .occurrence_information import OccurrenceInformation
from .occurrence_span_information import OccurrenceSpanInformation
from .other_diagnosis_information import OtherDiagnosisInformation
from .other_procedure_information import OtherProcedureInformation
from .patient_reason_for_visit import PatientReasonForVisit
from .set_or_clear_admitting_diagnosis import SetOrClearAdmittingDiagnosis
from .set_or_clear_diagnosis_related_group import SetOrClearDiagnosisRelatedGroup
from .set_or_clear_principal_diagnosis import SetOrClearPrincipalDiagnosis
from .set_or_clear_principal_procedure_information import SetOrClearPrincipalProcedureInformation
from .treatment_code_information import TreatmentCodeInformation
from .value_information import ValueInformation


class HealthCareCodeInformationUpdate(UniversalBaseModel):
    principal_diagnosis: typing.Optional[SetOrClearPrincipalDiagnosis] = pydantic.Field(default=None)
    """
    Set & Replace semantics.  If the id matches the existing principal_diagnosis, that diagnosis is updated in place.  If the entry has no id, it is created newly, its id will be in the response, and any existing principal_diagnosis is deleted and removed from any service line pointers.
    """

    other_diagnosis_information: typing.Optional[typing.List[OtherDiagnosisInformation]] = pydantic.Field(default=None)
    """
    Set & Replace semantics.  For each entry that has an id, any previous other_diagnosis_information by that id is updated in place.  For each entry without an id, it is created newly and its id will be in the response.  For each existing entry that was not referred to by id, it is deleted, including having it removed from any service line pointers.
    """

    admitting_diagnosis: typing.Optional[SetOrClearAdmittingDiagnosis] = pydantic.Field(default=None)
    """
    Set & Replace semantics.  If the id matches the existing admitting_diagnosis, that diagnosis is updated in place.  If the entry has no id, it is created newly, its id will be in the response, and any existing principal_diagnosis is deleted. This object only applies to 837i institutional claim forms.
    """

    patient_reasons_for_visit: typing.Optional[typing.List[PatientReasonForVisit]] = pydantic.Field(default=None)
    """
    Set & Replace semantics.  For each entry that has an id, any previous patient_reasons_for_visit by that id is updated in place.  For each entry without an id, it is created newly and its id will be in the response.  For each existing entry that was not referred to by id, it is deleted. This object only applies to 837i institutional claim forms.
    """

    external_causes_of_injury: typing.Optional[typing.List[ExternalCauseOfInjury]] = pydantic.Field(default=None)
    """
    Set & Replace semantics.  For each entry that has an id, any previous external_causes_of_injury by that id is updated in place.  For each entry without an id, it is created newly and its id will be in the response.  For each existing entry that was not referred to by id, it is deleted. This object only applies to 837i institutional claim forms.
    """

    diagnosis_related_groups: typing.Optional[SetOrClearDiagnosisRelatedGroup] = pydantic.Field(default=None)
    """
    Set & Replace semantics.  If the id matches the existing diagnosis_related_groups, that diagnosis_related_group is updated in place.  If the entry has no id, it is created newly, its id will be in the response, and any existing diagnosis_related_groups is deleted. This object only applies to 837i institutional claim forms.
    """

    principal_procedure: typing.Optional[SetOrClearPrincipalProcedureInformation] = pydantic.Field(default=None)
    """
    Set & Replace semantics.  If the id matches the existing principal_procedure, that principal_procedure is updated in place.  If the entry has no id, it is created newly, its id will be in the response, and any existing principal_procedure is deleted. This object only applies to 837i institutional claim forms.
    """

    other_procedure_information: typing.Optional[typing.List[OtherProcedureInformation]] = pydantic.Field(default=None)
    """
    Set & Replace semantics.  For each entry that has an id, any previous other_procedure_information by that id is updated in place.  For each entry without an id, it is created newly and its id will be in the response.  For each existing entry that was not referred to by id, it is deleted. This object only applies to 837i institutional claim forms.
    """

    occurrence_span_information: typing.Optional[typing.List[OccurrenceSpanInformation]] = pydantic.Field(default=None)
    """
    Set & Replace semantics.  For each entry that has an id, any previous occurrence_span_information by that id is updated in place.  For each entry without an id, it is created newly and its id will be in the response.  For each existing entry that was not referred to by id, it is deleted. This object only applies to 837i institutional claim forms.
    """

    occurrence_information: typing.Optional[typing.List[OccurrenceInformation]] = pydantic.Field(default=None)
    """
    Set & Replace semantics.  For each entry that has an id, any previous occurrence_information by that id is updated in place.  For each entry without an id, it is created newly and its id will be in the response.  For each existing entry that was not referred to by id, it is deleted. This object only applies to 837i institutional claim forms.
    """

    treatment_code_information: typing.Optional[typing.List[TreatmentCodeInformation]] = pydantic.Field(default=None)
    """
    Set & Replace semantics.  For each entry that has an id, any previous treatment_code_information by that id is updated in place.  For each entry without an id, it is created newly and its id will be in the response.  For each existing entry that was not referred to by id, it is deleted. This object only applies to 837i institutional claim forms.
    """

    value_information: typing.Optional[typing.List[ValueInformation]] = pydantic.Field(default=None)
    """
    Set & Replace semantics.  For each entry that has an id, any previous value_information by that id is updated in place.  For each entry without an id, it is created newly and its id will be in the response.  For each existing entry that was not referred to by id, it is deleted. This object only applies to 837i institutional claim forms.
    """

    condition_information: typing.Optional[typing.List[ConditionInformation]] = pydantic.Field(default=None)
    """
    Set & Replace semantics.  For each entry that has an id, any previous condition_information by that id is updated in place.  For each entry without an id, it is created newly and its id will be in the response.  For each existing entry that was not referred to by id, it is deleted. This object only applies to 837i institutional claim forms.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .billing_provider import BillingProvider
    from .billing_provider_secondary_identification import BillingProviderSecondaryIdentification
    from .billing_provider_secondary_identification_qualifier import BillingProviderSecondaryIdentificationQualifier
    from .billing_provider_update import BillingProviderUpdate
    from .billing_provider_update_with_optional_address import BillingProviderUpdateWithOptionalAddress
    from .encounter_provider import EncounterProvider
    from .encounter_provider_base import EncounterProviderBase
    from .initial_referring_provider import InitialReferringProvider
    from .initial_referring_provider_update import InitialReferringProviderUpdate
    from .initial_referring_provider_update_with_optional_address import (
        InitialReferringProviderUpdateWithOptionalAddress,
    )
    from .ordering_provider import OrderingProvider
    from .ordering_provider_optional import OrderingProviderOptional
    from .ordering_provider_update import OrderingProviderUpdate
    from .provider_id import ProviderId
    from .provider_secondary_identification import ProviderSecondaryIdentification
    from .provider_secondary_identification_qualifier import ProviderSecondaryIdentificationQualifier
    from .referring_provider import ReferringProvider
    from .referring_provider_secondary_identification import ReferringProviderSecondaryIdentification
    from .referring_provider_secondary_identification_qualifier import ReferringProviderSecondaryIdentificationQualifier
    from .referring_provider_update import ReferringProviderUpdate
    from .referring_provider_update_with_optional_address import ReferringProviderUpdateWithOptionalAddress
    from .rendering_provider import RenderingProvider
    from .rendering_provider_update import RenderingProviderUpdate
    from .rendering_provider_update_with_optional_address import RenderingProviderUpdateWithOptionalAddress
    from .supervising_provider import SupervisingProvider
    from .supervising_provider_secondary_identification import SupervisingProviderSecondaryIdentification
    from .supervising_provider_update import SupervisingProviderUpdate
    from .supervising_provider_update_with_optional_address import SupervisingProviderUpdateWithOptionalAddress
_dynamic_imports: typing.Dict[str, str] = {
    "BillingProvider": ".billing_provider",
    "BillingProviderSecondaryIdentification": ".billing_provider_secondary_identification",
    "BillingProviderSecondaryIdentificationQualifier": ".billing_provider_secondary_identification_qualifier",
    "BillingProviderUpdate": ".billing_provider_update",
    "BillingProviderUpdateWithOptionalAddress": ".billing_provider_update_with_optional_address",
    "EncounterProvider": ".encounter_provider",
    "EncounterProviderBase": ".encounter_provider_base",
    "InitialReferringProvider": ".initial_referring_provider",
    "InitialReferringProviderUpdate": ".initial_referring_provider_update",
    "InitialReferringProviderUpdateWithOptionalAddress": ".initial_referring_provider_update_with_optional_address",
    "OrderingProvider": ".ordering_provider",
    "OrderingProviderOptional": ".ordering_provider_optional",
    "OrderingProviderUpdate": ".ordering_provider_update",
    "ProviderId": ".provider_id",
    "ProviderSecondaryIdentification": ".provider_secondary_identification",
    "ProviderSecondaryIdentificationQualifier": ".provider_secondary_identification_qualifier",
    "ReferringProvider": ".referring_provider",
    "ReferringProviderSecondaryIdentification": ".referring_provider_secondary_identification",
    "ReferringProviderSecondaryIdentificationQualifier": ".referring_provider_secondary_identification_qualifier",
    "ReferringProviderUpdate": ".referring_provider_update",
    "ReferringProviderUpdateWithOptionalAddress": ".referring_provider_update_with_optional_address",
    "RenderingProvider": ".rendering_provider",
    "RenderingProviderUpdate": ".rendering_provider_update",
    "RenderingProviderUpdateWithOptionalAddress": ".rendering_provider_update_with_optional_address",
    "SupervisingProvider": ".supervising_provider",
    "SupervisingProviderSecondaryIdentification": ".supervising_provider_secondary_identification",
    "SupervisingProviderUpdate": ".supervising_provider_update",
    "SupervisingProviderUpdateWithOptionalAddress": ".supervising_provider_update_with_optional_address",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "BillingProvider",
    "BillingProviderSecondaryIdentification",
    "BillingProviderSecondaryIdentificationQualifier",
    "BillingProviderUpdate",
    "BillingProviderUpdateWithOptionalAddress",
    "EncounterProvider",
    "EncounterProviderBase",
    "InitialReferringProvider",
    "InitialReferringProviderUpdate",
    "InitialReferringProviderUpdateWithOptionalAddress",
    "OrderingProvider",
    "OrderingProviderOptional",
    "OrderingProviderUpdate",
    "ProviderId",
    "ProviderSecondaryIdentification",
    "ProviderSecondaryIdentificationQualifier",
    "ReferringProvider",
    "ReferringProviderSecondaryIdentification",
    "ReferringProviderSecondaryIdentificationQualifier",
    "ReferringProviderUpdate",
    "ReferringProviderUpdateWithOptionalAddress",
    "RenderingProvider",
    "RenderingProviderUpdate",
    "RenderingProviderUpdateWithOptionalAddress",
    "SupervisingProvider",
    "SupervisingProviderSecondaryIdentification",
    "SupervisingProviderUpdate",
    "SupervisingProviderUpdateWithOptionalAddress",
]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .insurance_adjustment_info import InsuranceAdjustmentInfo
    from .insurance_payment_info import InsurancePaymentInfo
    from .invalid_filters_error_type import InvalidFiltersErrorType
    from .inventory_record import InventoryRecord
    from .invoice_itemization_response import InvoiceItemizationResponse
    from .list_inventory_paged_response import ListInventoryPagedResponse
    from .non_insurance_adjustment_info import NonInsuranceAdjustmentInfo
    from .non_insurance_payment_info import NonInsurancePaymentInfo
    from .patient_adjustment_info import PatientAdjustmentInfo
    from .patient_ar_status import PatientArStatus
    from .patient_payment_allocation import PatientPaymentAllocation
    from .patient_payment_info import PatientPaymentInfo
    from .service_line_itemization import ServiceLineItemization
_dynamic_imports: typing.Dict[str, str] = {
    "InsuranceAdjustmentInfo": ".insurance_adjustment_info",
    "InsurancePaymentInfo": ".insurance_payment_info",
    "InvalidFiltersErrorType": ".invalid_filters_error_type",
    "InventoryRecord": ".inventory_record",
    "InvoiceItemizationResponse": ".invoice_itemization_response",
    "ListInventoryPagedResponse": ".list_inventory_paged_response",
    "NonInsuranceAdjustmentInfo": ".non_insurance_adjustment_info",
    "NonInsurancePaymentInfo": ".non_insurance_payment_info",
    "PatientAdjustmentInfo": ".patient_adjustment_info",
    "PatientArStatus": ".patient_ar_status",
    "PatientPaymentAllocation": ".patient_payment_allocation",
    "PatientPaymentInfo": ".patient_payment_info",
    "ServiceLineItemization": ".service_line_itemization",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "InsuranceAdjustmentInfo",
    "InsurancePaymentInfo",
    "InvalidFiltersErrorType",
    "InventoryRecord",
    "InvoiceItemizationResponse",
    "ListInventoryPagedResponse",
    "NonInsuranceAdjustmentInfo",
    "NonInsurancePaymentInfo",
    "PatientAdjustmentInfo",
    "PatientArStatus",
    "PatientPaymentAllocation",
    "PatientPaymentInfo",
    "ServiceLineItemization",
]



# This file was auto-generated by Fern from our API Definition.

import typing

from ......core import enum

T_Result = typing.TypeVar("T_Result")


class PatientReasonForVisitCodeQualifier(enum.StrEnum):
    CPR = "PR"
    """
    International Classification of Diseases Clinical Modification (ICD-9-CM) Patient's Reason for Visit
    """

    CAPR = "APR"
    """
    International Classification of Diseases Clinical Modification (ICD-10-CM) Patient's Reason for Visit
    """

    _UNKNOWN = "__PATIENTREASONFORVISITCODEQUALIFIER_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "PatientReasonForVisitCodeQualifier":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        cpr: typing.Callable[[], T_Result],
        capr: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is PatientReasonForVisitCodeQualifier.CPR:
            return cpr()
        if self is PatientReasonForVisitCodeQualifier.CAPR:
            return capr()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .....commons.types.user_id import UserId
from ...commons.types.task_status import TaskStatus


class TaskUpdateV3(UniversalBaseModel):
    status: typing.Optional[TaskStatus] = None
    assignee_user_id: typing.Optional[UserId] = None
    blocks_claim_submission: typing.Optional[bool] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        AdmittingDiagnosis,
        AdmittingDiagnosisCodeQualifier,
        AdmittingDiagnosisNew,
        ConditionCode,
        ConditionInformation,
        ConditionInformationCodeQualifier,
        ConditionInformationNew,
        D8Date,
        DiagnosisRelatedGroup,
        DiagnosisRelatedGroupCodeQualifier,
        DiagnosisRelatedGroupNew,
        ExternalCauseOfInjury,
        ExternalCauseOfInjuryCodeQualifier,
        ExternalCauseOfInjuryNew,
        HealthCareCodeInformation,
        HealthCareCodeInformationCreate,
        HealthCareCodeInformationGetAllResponse,
        HealthCareCodeInformationNew,
        HealthCareCodeInformationUpdate,
        IcdCode,
        MsdrgCode,
        OccurrenceCode,
        OccurrenceInformation,
        OccurrenceInformationCodeQualifier,
        OccurrenceInformationNew,
        OccurrenceSpanCode,
        OccurrenceSpanCodeQualifier,
        OccurrenceSpanInformation,
        OccurrenceSpanInformationNew,
        OtherDiagnosisInformation,
        OtherDiagnosisInformationCodeQualifier,
        OtherDiagnosisInformationNew,
        OtherProcedureInformation,
        OtherProcedureInformationCodeQualifier,
        OtherProcedureInformationNew,
        PatientReasonForVisit,
        PatientReasonForVisitCodeQualifier,
        PatientReasonForVisitNew,
        PresentOnAdmissionIndicatorCode,
        PrincipalDiagnosis,
        PrincipalDiagnosisCodeQualifier,
        PrincipalDiagnosisNew,
        PrincipalProcedureInformation,
        PrincipalProcedureInformationCodeQualifier,
        PrincipalProcedureInformationNew,
        Rd8Date,
        SetOrClearAdmittingDiagnosis,
        SetOrClearDiagnosisRelatedGroup,
        SetOrClearPrincipalDiagnosis,
        SetOrClearPrincipalProcedureInformation,
        TreatmentCode,
        TreatmentCodeInformation,
        TreatmentCodeInformationNew,
        TreatmentCodeQualifier,
        ValueCode,
        ValueCodeQualifier,
        ValueInformation,
        ValueInformationNew,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "AdmittingDiagnosis": ".types",
    "AdmittingDiagnosisCodeQualifier": ".types",
    "AdmittingDiagnosisNew": ".types",
    "ConditionCode": ".types",
    "ConditionInformation": ".types",
    "ConditionInformationCodeQualifier": ".types",
    "ConditionInformationNew": ".types",
    "D8Date": ".types",
    "DiagnosisRelatedGroup": ".types",
    "DiagnosisRelatedGroupCodeQualifier": ".types",
    "DiagnosisRelatedGroupNew": ".types",
    "ExternalCauseOfInjury": ".types",
    "ExternalCauseOfInjuryCodeQualifier": ".types",
    "ExternalCauseOfInjuryNew": ".types",
    "HealthCareCodeInformation": ".types",
    "HealthCareCodeInformationCreate": ".types",
    "HealthCareCodeInformationGetAllResponse": ".types",
    "HealthCareCodeInformationNew": ".types",
    "HealthCareCodeInformationUpdate": ".types",
    "IcdCode": ".types",
    "MsdrgCode": ".types",
    "OccurrenceCode": ".types",
    "OccurrenceInformation": ".types",
    "OccurrenceInformationCodeQualifier": ".types",
    "OccurrenceInformationNew": ".types",
    "OccurrenceSpanCode": ".types",
    "OccurrenceSpanCodeQualifier": ".types",
    "OccurrenceSpanInformation": ".types",
    "OccurrenceSpanInformationNew": ".types",
    "OtherDiagnosisInformation": ".types",
    "OtherDiagnosisInformationCodeQualifier": ".types",
    "OtherDiagnosisInformationNew": ".types",
    "OtherProcedureInformation": ".types",
    "OtherProcedureInformationCodeQualifier": ".types",
    "OtherProcedureInformationNew": ".types",
    "PatientReasonForVisit": ".types",
    "PatientReasonForVisitCodeQualifier": ".types",
    "PatientReasonForVisitNew": ".types",
    "PresentOnAdmissionIndicatorCode": ".types",
    "PrincipalDiagnosis": ".types",
    "PrincipalDiagnosisCodeQualifier": ".types",
    "PrincipalDiagnosisNew": ".types",
    "PrincipalProcedureInformation": ".types",
    "PrincipalProcedureInformationCodeQualifier": ".types",
    "PrincipalProcedureInformationNew": ".types",
    "Rd8Date": ".types",
    "SetOrClearAdmittingDiagnosis": ".types",
    "SetOrClearDiagnosisRelatedGroup": ".types",
    "SetOrClearPrincipalDiagnosis": ".types",
    "SetOrClearPrincipalProcedureInformation": ".types",
    "TreatmentCode": ".types",
    "TreatmentCodeInformation": ".types",
    "TreatmentCodeInformationNew": ".types",
    "TreatmentCodeQualifier": ".types",
    "ValueCode": ".types",
    "ValueCodeQualifier": ".types",
    "ValueInformation": ".types",
    "ValueInformationNew": ".types",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "AdmittingDiagnosis",
    "AdmittingDiagnosisCodeQualifier",
    "AdmittingDiagnosisNew",
    "ConditionCode",
    "ConditionInformation",
    "ConditionInformationCodeQualifier",
    "ConditionInformationNew",
    "D8Date",
    "DiagnosisRelatedGroup",
    "DiagnosisRelatedGroupCodeQualifier",
    "DiagnosisRelatedGroupNew",
    "ExternalCauseOfInjury",
    "ExternalCauseOfInjuryCodeQualifier",
    "ExternalCauseOfInjuryNew",
    "HealthCareCodeInformation",
    "HealthCareCodeInformationCreate",
    "HealthCareCodeInformationGetAllResponse",
    "HealthCareCodeInformationNew",
    "HealthCareCodeInformationUpdate",
    "IcdCode",
    "MsdrgCode",
    "OccurrenceCode",
    "OccurrenceInformation",
    "OccurrenceInformationCodeQualifier",
    "OccurrenceInformationNew",
    "OccurrenceSpanCode",
    "OccurrenceSpanCodeQualifier",
    "OccurrenceSpanInformation",
    "OccurrenceSpanInformationNew",
    "OtherDiagnosisInformation",
    "OtherDiagnosisInformationCodeQualifier",
    "OtherDiagnosisInformationNew",
    "OtherProcedureInformation",
    "OtherProcedureInformationCodeQualifier",
    "OtherProcedureInformationNew",
    "PatientReasonForVisit",
    "PatientReasonForVisitCodeQualifier",
    "PatientReasonForVisitNew",
    "PresentOnAdmissionIndicatorCode",
    "PrincipalDiagnosis",
    "PrincipalDiagnosisCodeQualifier",
    "PrincipalDiagnosisNew",
    "PrincipalProcedureInformation",
    "PrincipalProcedureInformationCodeQualifier",
    "PrincipalProcedureInformationNew",
    "Rd8Date",
    "SetOrClearAdmittingDiagnosis",
    "SetOrClearDiagnosisRelatedGroup",
    "SetOrClearPrincipalDiagnosis",
    "SetOrClearPrincipalProcedureInformation",
    "TreatmentCode",
    "TreatmentCodeInformation",
    "TreatmentCodeInformationNew",
    "TreatmentCodeQualifier",
    "ValueCode",
    "ValueCodeQualifier",
    "ValueInformation",
    "ValueInformationNew",
]



# This file was auto-generated by Fern from our API Definition.

import typing

from .....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .....core.request_options import RequestOptions
from .raw_client import AsyncRawV2Client, RawV2Client

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class V2Client:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawV2Client(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawV2Client:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawV2Client
        """
        return self._raw_client

    def submit_eligibility_check_availity(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.Any:
        """
        <Tip>Candid is deprecating support for this endpoint. It is instead recommended to use [Candid's Stedi passthrough endpoint](https://docs.joincandidhealth.com/api-reference/pre-encounter/eligibility-checks/v-1/post).
        For assistance with the transition, please reference the [Transitioning to Candid's New Eligibility Endpoint](https://support.joincandidhealth.com/hc/en-us/articles/34918552872980) document in the Candid Support Center.</Tip>

        **Availity has transitioned their GET endpoint to a POST endpoint. Candid has updated their pass-through integration to enable backwards compatibility for the GET endpoint so that customers do not have to immediately update their integrations.**

        **Candid recommends integrations with the [POST endpoint](https://docs.joincandidhealth.com/api-reference/eligibility/v-2/submit-eligibility-check-availity-post) to ensure the best possible integration experience. Given the transition, Availity’s documentation will be out of sync with this endpoint.**

        If you'd like access to this endpoint, please reach out to support@joincandidhealth.com with the subject line "Action: Activate Availity Eligibility API Endpoint

        This API is a wrapper around Availity's coverages API. Below are some helpful documentation links:

        - [Availity - Coverages 1.0.0 API](https://developer.availity.com/partner/documentation#c_coverages_references)
        - [Candid Availity Eligibility Integration Guide](https://support.joincandidhealth.com/hc/en-us/articles/24218441631892--Availity-Eligibility-Integration-Guide)

        A schema of the response object can be found here: [Availity Docs](https://developer.availity.com/partner/product/191210/api/190898#/Coverages_100/operation/%2Fcoverages%2F{id}/get)
        * Note Availity requires a free developer account to access this documentation.

        Check connection status of Availity API and partners here:
        - [Availity Trading Partner Connection Status](https://www.availity.com/status/)

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Any

        Examples
        --------
        from candid import CandidApiClient

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.eligibility.v_2.submit_eligibility_check_availity()
        """
        _response = self._raw_client.submit_eligibility_check_availity(request_options=request_options)
        return _response.data

    def submit_eligibility_check_availity_post(
        self, *, request: typing.Any, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.Any:
        """
        <Tip>Candid is deprecating support for this endpoint. It is instead recommended to use [Candid's Stedi passthrough endpoint](https://docs.joincandidhealth.com/api-reference/pre-encounter/eligibility-checks/v-1/post).
        For assistance with the transition, please reference the [Transitioning to Candid's New Eligibility Endpoint](https://support.joincandidhealth.com/hc/en-us/articles/34918552872980) document in the Candid Support Center.</Tip>

        If you'd like access to this endpoint, please reach out to support@joincandidhealth.com with the subject line "Action: Activate Availity Eligibility API Endpoint

        This API is a wrapper around Availity's coverages API. Below are some helpful documentation links:

        - [Availity - Coverages 1.0.0 API](https://developer.availity.com/partner/documentation#c_coverages_references)
        - [Candid Availity Eligibility Integration Guide](https://support.joincandidhealth.com/hc/en-us/articles/24218441631892--Availity-Eligibility-Integration-Guide)

        A schema of the response object can be found here: [Availity Docs](https://developer.availity.com/partner/product/191210/api/190898#/Coverages_100/operation/%2Fcoverages%2F{id}/get)
        * Note Availity requires a free developer account to access this documentation.

        Check connection status of Availity API and partners here:
        - [Availity Trading Partner Connection Status](https://www.availity.com/status/)

        Parameters
        ----------
        request : typing.Any

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Any

        Examples
        --------
        from candid import CandidApiClient

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.eligibility.v_2.submit_eligibility_check_availity_post(
            request={"key": "value"},
        )
        """
        _response = self._raw_client.submit_eligibility_check_availity_post(
            request=request, request_options=request_options
        )
        return _response.data


class AsyncV2Client:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawV2Client(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawV2Client:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawV2Client
        """
        return self._raw_client

    async def submit_eligibility_check_availity(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.Any:
        """
        <Tip>Candid is deprecating support for this endpoint. It is instead recommended to use [Candid's Stedi passthrough endpoint](https://docs.joincandidhealth.com/api-reference/pre-encounter/eligibility-checks/v-1/post).
        For assistance with the transition, please reference the [Transitioning to Candid's New Eligibility Endpoint](https://support.joincandidhealth.com/hc/en-us/articles/34918552872980) document in the Candid Support Center.</Tip>

        **Availity has transitioned their GET endpoint to a POST endpoint. Candid has updated their pass-through integration to enable backwards compatibility for the GET endpoint so that customers do not have to immediately update their integrations.**

        **Candid recommends integrations with the [POST endpoint](https://docs.joincandidhealth.com/api-reference/eligibility/v-2/submit-eligibility-check-availity-post) to ensure the best possible integration experience. Given the transition, Availity’s documentation will be out of sync with this endpoint.**

        If you'd like access to this endpoint, please reach out to support@joincandidhealth.com with the subject line "Action: Activate Availity Eligibility API Endpoint

        This API is a wrapper around Availity's coverages API. Below are some helpful documentation links:

        - [Availity - Coverages 1.0.0 API](https://developer.availity.com/partner/documentation#c_coverages_references)
        - [Candid Availity Eligibility Integration Guide](https://support.joincandidhealth.com/hc/en-us/articles/24218441631892--Availity-Eligibility-Integration-Guide)

        A schema of the response object can be found here: [Availity Docs](https://developer.availity.com/partner/product/191210/api/190898#/Coverages_100/operation/%2Fcoverages%2F{id}/get)
        * Note Availity requires a free developer account to access this documentation.

        Check connection status of Availity API and partners here:
        - [Availity Trading Partner Connection Status](https://www.availity.com/status/)

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Any

        Examples
        --------
        import asyncio

        from candid import AsyncCandidApiClient

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.eligibility.v_2.submit_eligibility_check_availity()


        asyncio.run(main())
        """
        _response = await self._raw_client.submit_eligibility_check_availity(request_options=request_options)
        return _response.data

    async def submit_eligibility_check_availity_post(
        self, *, request: typing.Any, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.Any:
        """
        <Tip>Candid is deprecating support for this endpoint. It is instead recommended to use [Candid's Stedi passthrough endpoint](https://docs.joincandidhealth.com/api-reference/pre-encounter/eligibility-checks/v-1/post).
        For assistance with the transition, please reference the [Transitioning to Candid's New Eligibility Endpoint](https://support.joincandidhealth.com/hc/en-us/articles/34918552872980) document in the Candid Support Center.</Tip>

        If you'd like access to this endpoint, please reach out to support@joincandidhealth.com with the subject line "Action: Activate Availity Eligibility API Endpoint

        This API is a wrapper around Availity's coverages API. Below are some helpful documentation links:

        - [Availity - Coverages 1.0.0 API](https://developer.availity.com/partner/documentation#c_coverages_references)
        - [Candid Availity Eligibility Integration Guide](https://support.joincandidhealth.com/hc/en-us/articles/24218441631892--Availity-Eligibility-Integration-Guide)

        A schema of the response object can be found here: [Availity Docs](https://developer.availity.com/partner/product/191210/api/190898#/Coverages_100/operation/%2Fcoverages%2F{id}/get)
        * Note Availity requires a free developer account to access this documentation.

        Check connection status of Availity API and partners here:
        - [Availity Trading Partner Connection Status](https://www.availity.com/status/)

        Parameters
        ----------
        request : typing.Any

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Any

        Examples
        --------
        import asyncio

        from candid import AsyncCandidApiClient

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.eligibility.v_2.submit_eligibility_check_availity_post(
                request={"key": "value"},
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.submit_eligibility_check_availity_post(
            request=request, request_options=request_options
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .canonical_clinical_trial_association import CanonicalClinicalTrialAssociation
from .canonical_non_insurance_payer_id import CanonicalNonInsurancePayerId
from .period import Period


class CanonicalNonInsurancePayerAssociation(UniversalBaseModel):
    id: CanonicalNonInsurancePayerId
    member_id: typing.Optional[str] = None
    period: typing.Optional[Period] = None
    clinical_trial_info: typing.Optional[typing.List[CanonicalClinicalTrialAssociation]] = pydantic.Field(default=None)
    """
    A patient cannot be associated with a given trial more than once
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .create_non_insurance_payer_request import CreateNonInsurancePayerRequest
    from .non_insurance_payer import NonInsurancePayer
    from .non_insurance_payer_address_update import (
        NonInsurancePayerAddressUpdate,
        NonInsurancePayerAddressUpdate_Remove,
        NonInsurancePayerAddressUpdate_Set,
    )
    from .non_insurance_payer_categories_page import NonInsurancePayerCategoriesPage
    from .non_insurance_payer_category_update import (
        NonInsurancePayerCategoryUpdate,
        NonInsurancePayerCategoryUpdate_Remove,
        NonInsurancePayerCategoryUpdate_Set,
    )
    from .non_insurance_payer_description_update import (
        NonInsurancePayerDescriptionUpdate,
        NonInsurancePayerDescriptionUpdate_Remove,
        NonInsurancePayerDescriptionUpdate_Set,
    )
    from .non_insurance_payer_id import NonInsurancePayerId
    from .non_insurance_payer_page import NonInsurancePayerPage
    from .non_insurance_payer_sort_field import NonInsurancePayerSortField
    from .non_insurance_payer_update_request import NonInsurancePayerUpdateRequest
    from .toggle_non_insurance_payer_enablement_request import ToggleNonInsurancePayerEnablementRequest
_dynamic_imports: typing.Dict[str, str] = {
    "CreateNonInsurancePayerRequest": ".create_non_insurance_payer_request",
    "NonInsurancePayer": ".non_insurance_payer",
    "NonInsurancePayerAddressUpdate": ".non_insurance_payer_address_update",
    "NonInsurancePayerAddressUpdate_Remove": ".non_insurance_payer_address_update",
    "NonInsurancePayerAddressUpdate_Set": ".non_insurance_payer_address_update",
    "NonInsurancePayerCategoriesPage": ".non_insurance_payer_categories_page",
    "NonInsurancePayerCategoryUpdate": ".non_insurance_payer_category_update",
    "NonInsurancePayerCategoryUpdate_Remove": ".non_insurance_payer_category_update",
    "NonInsurancePayerCategoryUpdate_Set": ".non_insurance_payer_category_update",
    "NonInsurancePayerDescriptionUpdate": ".non_insurance_payer_description_update",
    "NonInsurancePayerDescriptionUpdate_Remove": ".non_insurance_payer_description_update",
    "NonInsurancePayerDescriptionUpdate_Set": ".non_insurance_payer_description_update",
    "NonInsurancePayerId": ".non_insurance_payer_id",
    "NonInsurancePayerPage": ".non_insurance_payer_page",
    "NonInsurancePayerSortField": ".non_insurance_payer_sort_field",
    "NonInsurancePayerUpdateRequest": ".non_insurance_payer_update_request",
    "ToggleNonInsurancePayerEnablementRequest": ".toggle_non_insurance_payer_enablement_request",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "CreateNonInsurancePayerRequest",
    "NonInsurancePayer",
    "NonInsurancePayerAddressUpdate",
    "NonInsurancePayerAddressUpdate_Remove",
    "NonInsurancePayerAddressUpdate_Set",
    "NonInsurancePayerCategoriesPage",
    "NonInsurancePayerCategoryUpdate",
    "NonInsurancePayerCategoryUpdate_Remove",
    "NonInsurancePayerCategoryUpdate_Set",
    "NonInsurancePayerDescriptionUpdate",
    "NonInsurancePayerDescriptionUpdate_Remove",
    "NonInsurancePayerDescriptionUpdate_Set",
    "NonInsurancePayerId",
    "NonInsurancePayerPage",
    "NonInsurancePayerSortField",
    "NonInsurancePayerUpdateRequest",
    "ToggleNonInsurancePayerEnablementRequest",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2
from .....commons.types.emr_payer_crosswalk import EmrPayerCrosswalk
from .insurance_card_base import InsuranceCardBase


class InsuranceCardCreate(InsuranceCardBase):
    member_id: str
    payer_name: str
    payer_id: str
    rx_bin: typing.Optional[str] = None
    rx_pcn: typing.Optional[str] = None
    image_url_front: typing.Optional[str] = None
    image_url_back: typing.Optional[str] = None
    emr_payer_crosswalk: typing.Optional[EmrPayerCrosswalk] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ....core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .refund_reason import RefundReason


class RefundReasonUpdate_Set(UniversalBaseModel):
    value: RefundReason
    type: typing.Literal["set"] = "set"

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True


class RefundReasonUpdate_Remove(UniversalBaseModel):
    type: typing.Literal["remove"] = "remove"

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


RefundReasonUpdate = typing_extensions.Annotated[
    typing.Union[RefundReasonUpdate_Set, RefundReasonUpdate_Remove], pydantic.Field(discriminator="type")
]
